FKernalActionBuilder<T> class

Builder widget for performing actions (mutations) on endpoints.

FKernalActionBuilder<User>(
  action: 'createUser',
  builder: (context, perform, state) => ElevatedButton(
    onPressed: state.isLoading ? null : () => perform({'name': 'John'}),
    child: state.isLoading
      ? CircularProgressIndicator()
      : Text('Create User'),
  ),
)
Inheritance

Constructors

FKernalActionBuilder({Key? key, required String action, Map<String, String>? pathParams, required Widget builder(BuildContext context, Future<T> perform(dynamic payload), ResourceState<T> state), void onSuccess(T result)?, void onError(dynamic error)?, bool showSuccessSnackbar = false, String? successMessage, bool showErrorSnackbar = true})
const

Properties

action String
The endpoint ID for the action.
final
builder Widget Function(BuildContext context, Future<T> perform(dynamic payload), ResourceState<T> state)
Builder function that provides the perform callback and current state.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError → void Function(dynamic error)?
Callback when action fails.
final
onSuccess → void Function(T result)?
Callback when action completes successfully.
final
pathParams Map<String, String>?
Path parameters for the request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showErrorSnackbar bool
Whether to show a snackbar on error.
final
showSuccessSnackbar bool
Whether to show a snackbar on success.
final
successMessage String?
Success message for snackbar.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FKernalActionBuilder<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited