HiveStorageProvider class

Default Hive-based storage provider.

Implemented types

Constructors

HiveStorageProvider(String boxName)

Properties

boxName String
final
hashCode int
The hash code for this object.
no setterinherited
keys Iterable
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
override
close() Future<void>
override
delete(String key) Future<void>
override
get(String key) Future
override
init() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, dynamic value) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited