ValueSlice<T> class

A specialized local slice for simple value types.

Inheritance
Implementers

Constructors

ValueSlice(T initialValue)

Properties

canUndo bool
Whether undo is available.
no setterinherited
enableHistory bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
maxHistoryLength int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → T
The current state value.
no setterinherited
value ↔ T
The current value.
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearHistory() → void
Clears history.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset(T initialState) → void
Resets to initial state (if you store it).
inherited
setState(T newState) → void
Updates the state with a new value.
inherited
toString() String
A string representation of this object.
inherited
undo() → void
Undoes the last state change (if history is enabled).
inherited
update(T updater(T current)) → void
Updates the state using a function that receives the current state.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited