ResourceCubit<T> class abstract

A BLoC (Cubit) that automatically syncs with an FKernal resource.

Users must add flutter_bloc to their dependencies to use this.

Constructors

ResourceCubit(String endpointId, {Map<String, dynamic>? params, Map<String, String>? pathParams})

Properties

endpointId String
final
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
params Map<String, dynamic>?
final
pathParams Map<String, String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ResourceState<T>
The current state.
no setterinherited
stream Stream<ResourceState<T>>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
emit(ResourceState<T> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fetch({bool forceRefresh = false}) Future<T>
Fetches or refreshes the data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<ResourceState<T>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited