FirebaseNetworkClient class

Firebase Implementation of INetworkClient. Fully utilizes Firestore, Auth, and Storage.

Implemented types

Constructors

FirebaseNetworkClient({String baseUrl = ''})

Properties

baseUrl String
Base URL for the client.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelAll() → void
Cancels all pending requests.
override
dispose() → void
Disposes the client.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<T>(Endpoint endpoint, {Map<String, dynamic>? queryParams, Map<String, String>? pathParams, dynamic body}) Future<T>
Executes a request for a given endpoint.
override
toString() String
A string representation of this object.
inherited
watch<T>(Endpoint endpoint, {Map<String, dynamic>? queryParams, Map<String, String>? pathParams}) Stream<T>
Watches an endpoint for changes (Streams).
override

Operators

operator ==(Object other) bool
The equality operator.
inherited