ResourceSignal<T> class

A Signal that reactively reflects an FKernal resource state.

Users must add signals_flutter to their dependencies to use this.

Constructors

ResourceSignal(String endpointId, {Map<String, dynamic>? params, Map<String, String>? pathParams})

Properties

endpointId String
final
hashCode int
The hash code for this object.
no setterinherited
params Map<String, dynamic>?
final
pathParams Map<String, String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signalInstance → Signal<ResourceState<T>>
The signal instance for watching/effects.
no setter
state ResourceState<T>
The current state as a signal.
no setter

Methods

dispose() → void
fetch({bool forceRefresh = false}) Future<T>
Fetches or refreshes the data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited