Environment enum
Environment configuration for the app.
- Inheritance
- Available extensions
Values
- development → const Environment
-
Development environment with verbose logging.
- staging → const Environment
-
Staging environment for testing.
- production → const Environment
-
Production environment with minimal logging.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isDevelopment → bool
-
Available on Environment, provided by the EnvironmentX extension
Whether this is a development environment.no setter - isProduction → bool
-
Available on Environment, provided by the EnvironmentX extension
Whether this is a production environment.no setter - isStaging → bool
-
Available on Environment, provided by the EnvironmentX extension
Whether this is a staging environment.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldLog → bool
-
Available on Environment, provided by the EnvironmentX extension
Whether verbose logging should be enabled.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Environment> - A constant List of the values in this enum, in order of their declaration.