FKernalModel class abstract
Interface for models that support validation and serialization.
Implement this interface to allow ApiClient to automatically:
- Validate the model before sending the request.
- Serialize the model to JSON.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes the model to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void - Validates the model's data.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited