HistoryLocalState<T> class
A local state adapter with history/undo support.
- Inheritance
-
- Object
- ChangeNotifier
- LocalStateAdapter<
T> - HistoryLocalState
Constructors
- HistoryLocalState(T initialState, {int maxHistoryLength = 50})
Properties
- canUndo → bool
-
Whether undo is available.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- maxHistoryLength → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → T
-
Gets the current state value.
no setteroverride
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clearHistory(
) → void - Clears history.
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setState(
T newState) → void -
Updates the state with a new value.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
undo(
) → void - Undoes the last state change.
-
update(
T updater(T current)) → void -
Updates the state using a function.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited