ResourceStore<T> class
A MobX Store that automatically syncs with an FKernal resource.
Users must add mobx to their dependencies to use this.
Constructors
Properties
- context → ReactiveContext
-
Override this method to use a custom context.
no setterinherited
- endpointId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
params
→ Map<
String, dynamic> ? -
finalinherited
-
pathParams
→ Map<
String, String> ? -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ ResourceState<
T> -
getter/setter pairinherited
Methods
-
dispose(
) → void -
inherited
-
fetch(
{bool forceRefresh = false}) → Future< T> -
Fetches or refreshes the data.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited